Crate arena_alloc

source ·

Structs

  • A fixed size arena that can be used to allocate memory for arbitrary types.

Traits

  • A trait for initialization of a type that is stored in an arena and requires a circular reference to itself.