pub trait Init {
type InitArg;
// Required method
fn init(me: &mut MaybeUninit<Self>, arg: Self::InitArg)
where Self: Sized;
}Expand description
A trait for initialization of a type that is stored in an arena and requires a circular reference to itself to initialize.
Required Associated Types
Required Methods
fn init(me: &mut MaybeUninit<Self>, arg: Self::InitArg)where
Self: Sized,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".